send2trash: Send file to trash natively under Mac OS X, Windows and Linux
=========================================================================

Description
-----------

Send file to trash natively under Mac OS X, Windows and Linux.

License
-------

BSD License

Upstream Contact
----------------

https://pypi.org/project/Send2Trash/

